==> airpackage-0.0.9.tar.gz: lib/themes/colors.dart <==
import 'package:flutter/material.dart';

@immutable
class SocialColors {
  final Color twitter;
  final Color youtube;
  final Color facebook;
  final Color instagram;
  final Color pinterest;

  const SocialColors({
    this.twitter = const Color(0xFF55ACEE),
    this.youtube = const Color(0xFFCE1312),
    this.facebook = const Color(0xFF3B5998),
    this.instagram = const Color(0xFFA032AC),
    this.pinterest = const Color(0xFF9E0718),
  });
}

@immutable
class TextColors {
  final Color dark;
  final Color ligth;
  final Color white;

  const TextColors({
    this.dark = const Color(0xFFF1F1F1),
    this.ligth = const Color(0xFF4A4A4A),
    this.white = const Color(0xFFFFFFFF),
  });
}

@immutable
class StatusColors {
  final Color active;
  final Color inactive;
  final Color archieve;

  const StatusColors({
    this.active = const Color(0xFF299F6F),
    this.inactive = const Color(0xFFE41E37),
    this.archieve = const Color(0xFF4A4A4A),
  });
}

@immutable
class ActionsColors {
  final Color info;
  final Color error;
  final Color success;
  final Color warning;

  const ActionsColors({
    this.info = const Color(0xFF30A4F3),
    this.error = const Color(0xFFF22E49),
    this.success = const Color(0xFF40BD8A),
    this.warning = const Color(0xFFFCB848),
  });
}

@immutable
class CategoriesColors {
  final Color pet;
  final Color kids;
  final Color beer;
  final Color music;
  final Color sports;
  final Color health;
  final Color travel;
  final Color beauty;
  final Color politic;
  final Color culture;
  final Color fashion;
  final Color fitness;
  final Color business;
  final Color activism;
  final Color tecnology;
  final Color nutrition;
  final Color lifestyle;
  final Color education;
  final Color enviroment;
  final Color gastronomy;
  final Color literature;
  final Color automotive;
  final Color martialArt;
  final Color construction;
  final Color entertainment;
  final Color friendsFamily;

  const CategoriesColors({
    this.pet = const Color(0xFFE37E35),
    this.kids = const Color(0xFF9C27B0),
    this.beer = const Color(0xFFDA126B),
    this.music = const Color(0xFF424242),
    this.sports = const Color(0xFF0D47A1),
    this.health = const Color(0xFF39B64B),
    this.travel = const Color(0xFF26D3BD),
    this.beauty = const Color(0xFF6633AA),
    this.politic = const Color(0xFF2ACDA8),
    this.culture = const Color(0xFF00CED1),
    this.fashion = const Color(0xFFF6C223),
    this.fitness = const Color(0xFF15C7F6),
    this.business = const Color(0xFF1FCA1E),
    this.activism = const Color(0xFFA41023),
    this.tecnology = const Color(0xFF24B4CF),
    this.nutrition = const Color(0xFF894312),
    this.lifestyle = const Color(0xFFD32424),
    this.education = const Color(0xFFAFCE19),
    this.enviroment = const Color(0xFF50C064),
    this.gastronomy = const Color(0xFFFA9000),
    this.literature = const Color(0xFF228ABD),
    this.automotive = const Color(0xFFD0021B),
    this.martialArt = const Color(0xFFCA0412),
    this.construction = const Color(0xFFD8AE3A),
    this.entertainment = const Color(0xFF414BB3),
    this.friendsFamily = const Color(0xFFF24733),
  });
}

class AirColors {
  AirColors._();

  static const MaterialColor primary = MaterialColor(
    0xFFED276A,
    <int, Color>{
      100: Color(0xFFFFE7EF),
      300: Color(0xFFEF4C82),
      500: Color(0xFFED276A),
      800: Color(0xFFCE215B),
      1000: Color(0xFFA41444),
    },
  );
  static const MaterialColor secondary = MaterialColor(
    0xFF8E2785,
    <int, Color>{
      500: Color(0xFF8E2785),
    },
  );
  static const MaterialColor gray = MaterialColor(
    0xFFCDCDCD,
    <int, Color>{
      300: Color(0xFFE8E8E8),
      500: Color(0xFFCDCDCD),
      800: Color(0xFF989898),
      1000: Color(0xFF4A4A4A),
    },
  );
  static const MaterialColor white = MaterialColor(
    0xFFFFFFFF,
    <int, Color>{
      500: Color(0xFFFFFFFF),
    },
  );
  static const StatusColors status = const StatusColors();
  static const SocialColors socials = const SocialColors();
  static const ActionsColors actions = const ActionsColors();
  static const CategoriesColors categories = const CategoriesColors();
  static const TextColors text = const TextColors();
}

==> airpackage-0.0.10.tar.gz: lib/themes/colors.dart <==
import 'package:flutter/material.dart';

@immutable
class SocialColors {
  final Color twitter;
  final Color youtube;
  final Color facebook;
  final Color instagram;
  final Color pinterest;

  const SocialColors({
    this.twitter = const Color(0xFF55ACEE),
    this.youtube = const Color(0xFFCE1312),
    this.facebook = const Color(0xFF3B5998),
    this.instagram = const Color(0xFFA032AC),
    this.pinterest = const Color(0xFF9E0718),
  });
}

@immutable
class TextColors {
  final Color dark;
  final Color ligth;
  final Color white;

  const TextColors({
    this.dark = const Color(0xFF4A4A4A),
    this.ligth = const Color(0xFFF1F1F1),
    this.white = const Color(0xFFFFFFFF),
  });
}

@immutable
class StatusColors {
  final Color active;
  final Color inactive;
  final Color archieve;

  const StatusColors({
    this.active = const Color(0xFF299F6F),
    this.inactive = const Color(0xFFE41E37),
    this.archieve = const Color(0xFF4A4A4A),
  });
}

@immutable
class ActionsColors {
  final Color info;
  final Color error;
  final Color success;
  final Color warning;

  const ActionsColors({
    this.info = const Color(0xFF30A4F3),
    this.error = const Color(0xFFF22E49),
    this.success = const Color(0xFF40BD8A),
    this.warning = const Color(0xFFFCB848),
  });
}

@immutable
class CategoriesColors {
  final Color pet;
  final Color kids;
  final Color beer;
  final Color music;
  final Color sports;
  final Color health;
  final Color travel;
  final Color beauty;
  final Color politic;
  final Color culture;
  final Color fashion;
  final Color fitness;
  final Color business;
  final Color activism;
  final Color tecnology;
  final Color nutrition;
  final Color lifestyle;
  final Color education;
  final Color enviroment;
  final Color gastronomy;
  final Color literature;
  final Color automotive;
  final Color martialArt;
  final Color construction;
  final Color entertainment;
  final Color friendsFamily;

  const CategoriesColors({
    this.pet = const Color(0xFFE37E35),
    this.kids = const Color(0xFF9C27B0),
    this.beer = const Color(0xFFDA126B),
    this.music = const Color(0xFF424242),
    this.sports = const Color(0xFF0D47A1),
    this.health = const Color(0xFF39B64B),
    this.travel = const Color(0xFF26D3BD),
    this.beauty = const Color(0xFF6633AA),
    this.politic = const Color(0xFF2ACDA8),
    this.culture = const Color(0xFF00CED1),
    this.fashion = const Color(0xFFF6C223),
    this.fitness = const Color(0xFF15C7F6),
    this.business = const Color(0xFF1FCA1E),
    this.activism = const Color(0xFFA41023),
    this.tecnology = const Color(0xFF24B4CF),
    this.nutrition = const Color(0xFF894312),
    this.lifestyle = const Color(0xFFD32424),
    this.education = const Color(0xFFAFCE19),
    this.enviroment = const Color(0xFF50C064),
    this.gastronomy = const Color(0xFFFA9000),
    this.literature = const Color(0xFF228ABD),
    this.automotive = const Color(0xFFD0021B),
    this.martialArt = const Color(0xFFCA0412),
    this.construction = const Color(0xFFD8AE3A),
    this.entertainment = const Color(0xFF414BB3),
    this.friendsFamily = const Color(0xFFF24733),
  });
}

class AirColors {
  AirColors._();

  static const MaterialColor primary = MaterialColor(
    0xFFED276A,
    <int, Color>{
      100: Color(0xFFFFE7EF),
      300: Color(0xFFEF4C82),
      500: Color(0xFFED276A),
      800: Color(0xFFCE215B),
      1000: Color(0xFFA41444),
    },
  );
  static const MaterialColor secondary = MaterialColor(
    0xFF8E2785,
    <int, Color>{
      500: Color(0xFF8E2785),
    },
  );
  static const MaterialColor gray = MaterialColor(
    0xFFCDCDCD,
    <int, Color>{
      300: Color(0xFFE8E8E8),
      500: Color(0xFFCDCDCD),
      800: Color(0xFF989898),
      1000: Color(0xFF4A4A4A),
    },
  );
  static const MaterialColor white = MaterialColor(
    0xFFFFFFFF,
    <int, Color>{
      500: Color(0xFFFFFFFF),
    },
  );
  static const StatusColors status = const StatusColors();
  static const SocialColors socials = const SocialColors();
  static const ActionsColors actions = const ActionsColors();
  static const CategoriesColors categories = const CategoriesColors();
  static const TextColors text = const TextColors();
}
